Documentation
¶
Overview ¶
Package services implements business logic of pmm-managed.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Supervisor ¶
type Supervisor interface {
// Start installs and starts a service.
Start(ctx context.Context, config *servicelib.Config) error
// Start stops and uninstalls a service.
Stop(ctx context.Context, name string) error
// Status returns nil if service is installed and running.
// It returns error otherwise or if service status can't be determined.
Status(ctx context.Context, name string) error
}
Supervisor is an interface for supervisor.Supervisor for mock generation.
Source Files
¶
- base.go
- supervisor.go
Directories
¶
| Path | Synopsis |
|---|---|
|
Package consul provides facilities for working with Consul.
|
Package consul provides facilities for working with Consul. |
|
Package grafana provides facilities for working with Grafana.
|
Package grafana provides facilities for working with Grafana. |
|
Package mysql contains business logic of working with Remote MySQL instances.
|
Package mysql contains business logic of working with Remote MySQL instances. |
|
Package postgresql contains business logic of working with Remote PostgreSQL instances.
|
Package postgresql contains business logic of working with Remote PostgreSQL instances. |
|
Package prometheus contains business logic of working with Prometheus.
|
Package prometheus contains business logic of working with Prometheus. |
|
Package qan contains business logic of working with QAN and qan-agent on PMM Server node.
|
Package qan contains business logic of working with QAN and qan-agent on PMM Server node. |
|
Package rds contains business logic of working with AWS RDS.
|
Package rds contains business logic of working with AWS RDS. |
|
Package remote contains business logic of working with all Remote instances.
|
Package remote contains business logic of working with all Remote instances. |
|
Package supervisor provides facilities for working with system process supervisors.
|
Package supervisor provides facilities for working with system process supervisors. |
|
Package telemetry provides Call Home functionality.
|
Package telemetry provides Call Home functionality. |
Click to show internal directories.
Click to hide internal directories.