Documentation
¶
Overview ¶
Package consul provides facilities for working with Consul.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client represents a client for Consul API. All keys in KV operations are prefixed to avoid collisions.
func NewClient ¶
NewClient creates a new client for given Consul address.
func (*Client) DeleteKV ¶
DeleteKV deletes given key from Consul.
func (*Client) GetKV ¶
GetKV returns value for a given key from Consul, or nil, if key does not exist.
func (*Client) GetNodes ¶ added in v1.15.0
GetNodes returns list of nodes.
Source Files
¶
- consul.go
Click to show internal directories.
Click to hide internal directories.